package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Null;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.RSASSAPSSparams;
import cn.com.infosec.asn1.teletrust.TeleTrusTObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import java.security.Signature;

class X509SignatureUtil {
   private static final ASN1Null derNull = new DERNull();
   // $FF: synthetic field
   static Class class$0;

   static void setSignatureParameters(Signature param0, DEREncodable param1) {
      // $FF: Couldn't be decompiled
   }

   static String getSignatureName(AlgorithmIdentifier sigAlgId) {
      DEREncodable var1;
      if ((var1 = sigAlgId.getParameters()) != null && !derNull.equals(var1)) {
         if (sigAlgId.getObjectId().equals(PKCSObjectIdentifiers.id_RSASSA_PSS)) {
            RSASSAPSSparams sigAlgId2 = RSASSAPSSparams.getInstance(var1);
            return getDigestAlgName(sigAlgId2.getHashAlgorithm().getObjectId()) + "withRSAandMGF1";
         }

         if (sigAlgId.getObjectId().equals(X9ObjectIdentifiers.ecdsa_with_SHA2)) {
            ASN1Sequence sigAlgId1 = ASN1Sequence.getInstance(var1);
            return getDigestAlgName((DERObjectIdentifier)sigAlgId1.getObjectAt(0)) + "withECDSA";
         }
      }

      return sigAlgId.getObjectId().getId();
   }

   private static String getDigestAlgName(DERObjectIdentifier digestAlgOID) {
      if (PKCSObjectIdentifiers.md5.equals(digestAlgOID)) {
         return "MD5";
      } else if (OIWObjectIdentifiers.idSHA1.equals(digestAlgOID)) {
         return "SHA1";
      } else if (NISTObjectIdentifiers.id_sha224.equals(digestAlgOID)) {
         return "SHA224";
      } else if (NISTObjectIdentifiers.id_sha256.equals(digestAlgOID)) {
         return "SHA256";
      } else if (NISTObjectIdentifiers.id_sha384.equals(digestAlgOID)) {
         return "SHA384";
      } else if (NISTObjectIdentifiers.id_sha512.equals(digestAlgOID)) {
         return "SHA512";
      } else if (TeleTrusTObjectIdentifiers.ripemd128.equals(digestAlgOID)) {
         return "RIPEMD128";
      } else if (TeleTrusTObjectIdentifiers.ripemd160.equals(digestAlgOID)) {
         return "RIPEMD160";
      } else if (TeleTrusTObjectIdentifiers.ripemd256.equals(digestAlgOID)) {
         return "RIPEMD256";
      } else {
         return CryptoProObjectIdentifiers.gostR3411.equals(digestAlgOID) ? "GOST3411" : digestAlgOID.getId();
      }
   }
}
